#!/bin/bash
# 
# SCRIPT NAME:
# post-install.sh
#
# AUTHOR:
# Severin Kaderli <severin.kaderli@gmail.com>
#
# DESCRIPTION:
# This is the post-install script for my dotfiles. It should be only run
# after install.sh has been run and the system has been rebooted. This script
# installs global npm packages.
#
# USAGE:
# ./post-install.sh
. ./system/.local/bin/utils.sh

#######################################
# Configuration variables
#######################################
# Array of npm packages which should be installed globally
NPM_PACKAGES=(
    "@vue/cli"
    "eslint"
    "gatsby-cli"
    "npm-check-updates"
)

RUST_COMPONENTS=(
    "rls-preview"
    "rustfmt-preview"
)

#######################################
# Main code
#######################################
print_header "Installing global npm packages"
npm i -g "${NPM_PACKAGES[@]}"

print_header "Install Rust toolchain and components"
rustup toolchain install beta
rustup default beta
rustup component add "${RUST_COMPONENTS[@]}"